How to use?
===========

You can import cookieconsent from ``js.cookieconsent`` and ``need`` it where
you want these resources to be included on a page::

  >>> from js.cookieconsent import cookieconsent
  >>> cookieconsent.need()


.. _`fanstatic`: http://fanstatic.org
